from docutils import core, io

def html_parts(input_string, source_path=None,   
               destination_path=None,
               input_encoding='unicode', doctitle=True,
               initial_header_level=1):
    overrides = {'input_encoding': input_encoding,
                 'doctitle_xform': doctitle,
                 'syntax_highlight': 'short',
                 'initial_header_level': initial_header_level}
    parts = core.publish_parts(
        source=input_string, source_path=source_path,
        destination_path=destination_path,
        writer_name='html', settings_overrides=overrides)
    return parts


def html_body(input_string, source_path=None, destination_path=None,
              input_encoding='unicode', output_encoding='unicode',
              doctitle=True, initial_header_level=1):
    parts = html_parts(
        input_string=input_string, source_path=source_path,
        destination_path=destination_path,
        input_encoding=input_encoding, doctitle=doctitle,
        initial_header_level=initial_header_level)
    fragment = parts['html_body']
    if output_encoding != 'unicode':
        fragment = fragment.encode(output_encoding)
    return fragment



import os

DEFAULT_FILE = os.path.join(
    os.path.dirname(os.path.realpath(__file__)),'templates','index.rst')
TEMPLATE_DIR = os.path.join( os.path.dirname(os.path.realpath(__file__)),'templates')
STATIC_DIR = os.path.join( os.path.dirname(os.path.realpath(__file__)),'static')
DEFAULT_PORT = 5676
DEFAULT_BROWSER = 'firefox'
SECRET_KEY = 'JO34h#F*$HFHA@#&('



from flask import Flask, render_template, request, url_for, jsonify
from flask.ext.socketio import SocketIO, emit

import os, sys

from instant_rst.rst import html_body

from instant_rst.config import DEFAULT_FILE, SECRET_KEY,TEMPLATE_DIR,STATIC_DIR

app = Flask(__name__,
        static_folder=STATIC_DIR,
        template_folder=TEMPLATE_DIR)
# app.debug = True
app.config['SECRET_KEY'] = SECRET_KEY

socketio = SocketIO(app)


@app.route("/", methods=['GET','PUT','POST','DELETE'])
def index():
    if request.method == 'PUT' or request.method == 'POST':
        f = request.form.get('file', '')
        p = request.form.get('p', '-1')
        if os.path.isfile(f):
            with open(f,'r') as rst:
                d = html_body(rst.read().decode('utf8'))
            socketio.emit('updatingContent', {'HTML': d,'p':p})
            return jsonify(success='true',file=f, p=p)
        elif p != '-1':
            socketio.emit('updatingContent', {'p':p})
            return jsonify(success='true',file=f, p=p)
        else:
            return jsonify(success='false',info='File Not Exist',file=f)


    elif request.method == 'DELETE':

        socketio.emit('die', {'exit': 1})
        shutdown_server()

    elif request.method == 'GET':

        f = request.args.get('file', DEFAULT_FILE)
        if os.path.isfile(f):
            with open(f,'r') as rst:
                d = html_body(rst.read().decode('utf8'))
                return render_template('index.html',HTML=d)
        else:
            return render_template('index.html')

def shutdown_server():
    exit = request.environ.get('werkzeug.server.shutdown')
    if exit is None:
        sys.exit()
    exit()

@socketio.on('my event')
def test_message(message):
    emit('my response', {'data': 'got it!'})




import argparse

from instant_rst.config import DEFAULT_FILE, DEFAULT_PORT, DEFAULT_BROWSER

def parse():
    parser = argparse.ArgumentParser(description='Preview rst Instantly')
    parser.add_argument('-f', '--file', dest='filename',
                default=DEFAULT_FILE,
                help='The local filename for Converting')
    parser.add_argument('-b', '--browser', dest='browser',
                default='firefox',
                help='The browser command for viewing')
    parser.add_argument('-p', '--port', dest='port',
                default='5676',
                help='The port for server to use')
    return parser.parse_args()



#!/usr/bin/env python2
# -*- coding: utf-8 -*-
import urllib,urllib2

def get(url, headers={}):
    req = urllib2.Request(
        url = url,
        headers = headers
    )
    f = urllib2.urlopen(req)
    con = f.read()
    return {'code':f.getcode(), 'content':con}

def post(url, data, headers={}):
    req = urllib2.Request(
        url = url,
        headers = headers
    )
    f = urllib2.urlopen(req, urllib.urlencode(data))
    con = f.read()
    return {'code':f.getcode(), 'content':con}

